/*
 * alsa.h
 *
 * Function declarations for alsa.c
 *
 * Copyright (c) 2004 nash e.f. <nash@solace.net>
 *
 */
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <poll.h>
#include <alsa/asoundlib.h>

#ifndef CUTLASS_AUDIO_ALSA_H
#define CUTLASS_AUDIO_ALSA_H

/**
 * ALSA Sound library capture and playback support.
 */


//// A wrapper structure for 
//
typedef struct alsa_handle
{
    //// the cutlass driver handle identifier
    int handle_id;

    //// the ALSA audio handle
    snd_pcm_t *pcm;
    int pcm_rate;

    //// the audio mode's callback function
    int (*callback)(int);
} alsa_handle_t;

////
//
/* FIX ME: These should be removed in favor of user-configured parameters
 * that are set somewhere. Bleah. Easiest just to do this, at the moment. */
#define DEFAULT_ALSA_AUDIO_DEVICE               "plughw:0,0"
#define CUTLASS_ALSA_DEFAULT_CHANNELS           2
#define CUTLASS_ALSA_DEFAULT_RATE               22050
#define CUTLASS_ALSA_DEFAULT_FRAMES             4096
#define CUTLASS_ALSA_DEFAULT_START_THRESHOLD    0U
#define CUTLASS_DEFAULT_WAIT                    1000
//// 
//

//// Startup audio on a handle.
int alsa_startup(cutlass_audio_t *handle);

//// Create a new PCM stream handle for playback
int open_alsa_playback(cutlass_audio_t *handle, const char *name);

//// Create a new PCM stream handle for capture
int open_alsa_capture(cutlass_audio_t *handle, const char *name);

int open_alsa_handle( cutlass_audio_t *handle,
                      const char *name,
                      snd_pcm_stream_t dir);

int
close_alsa_handle(cutlass_audio_t *audio_handle);

int configure_alsa_handle(cutlass_audio_t *handle);

int capture_alsa_loop (cutlass_audio_t *handle);

int
alsa_handle_reset(cutlass_audio_t *handle);

int
alsa_capture_sync(cutlass_t *cut_handle, cutlass_audio_t *capture, long *frames);

int
alsa_capture_audio( cutlass_t *cut_handle,
                    cutlass_audio_t *capture,
                    cutlass_audio_pcm_t *audio_data);
int
alsa_capture_commit(  cutlass_t *cut_handle,
                      cutlass_audio_t *capture,
                      cutlass_audio_pcm_t *audio_data);

//// 
// A simple macro for turning error codes into Strings
#define cutlass_alsa_strerror(i) (err_msg_table[i]);

#endif /* CUTLASS_AUDIO_ALSA_H */
