/*
 * files.h
 *
 * Function declarations for files.c
 *
 * Copyright (c) 2004 Todd MacDermid <tmacd@synacklabs.net>
 *
 */

#ifndef FILE_RECV_H
#define FILE_RECV_H

#ifdef __cplusplus
extern "C" {
#endif

int
file_init_pack(cutlass_t *cut_header, uint8_t *packet,
               struct cutlass_file_init_hdr *header);

int
file_init_unpack(cutlass_t *cut_handle, uint8_t *packet,
                 struct cutlass_file_init_hdr *header);

int
cutlass_file_offer(cutlass_t *cut_handle, uint8_t *, char *filename);

int
cutlass_file_offer_all(cutlass_t *cut_handle, char *filename);

int
cutlass_file_request_process(cutlass_t *cut_handle, conn_t *conn, 
                             request_t *file_request);

int
cutlass_file_cancel_recv(cutlass_t *cut_handle, conn_t *conn, 
                         uint8_t channel_id);

int
cutlass_file_start_recv(cutlass_t *cut_handle, conn_t *conn, 
                        uint8_t channel_id, char *file_name, int overwrite);

int
cutlass_file_accept(cutlass_t *cut_handle, struct cut_action_obj *action_obj, 
                    char *local_name);

int
cutlass_file_reject(cutlass_t *cut_handle, struct cut_action_obj *action_obj);

void
file_info_destroy(cutlass_t *cut_handle, struct file_transit_info *file_info);

int
cutlass_file_init(cutlass_t *cut_handle, conn_t *conn,
		  struct file_transit_info *file_info,
		  struct timespec *now);

int
cutlass_file_init_parse(cutlass_t *cut_handle, conn_t *conn, 
			uint8_t *clear_packet, 
			struct cutlass_packet_hdr *packet_info,
			struct timespec *now);

int
cutlass_file_init_ack(cutlass_t *cut_handle, conn_t *conn,
                      struct file_transit_info *file_info, 
                      uint8_t *clear_packet,
                      struct timespec *now);
int
cutlass_file_init_ack_parse(cutlass_t *cut_handle, conn_t *conn, 
			uint8_t *clear_packet, 
			struct cutlass_packet_hdr *packet_info,
			struct timespec *now);

int
cutlass_file_send(cutlass_t *cut_handle, conn_t *conn,
			 struct file_transit_info *file_info, 
			 struct timespec *now);

int
cutlass_file_send_parse(cutlass_t *cut_handle, conn_t *conn, 
			uint8_t *clear_packet, 
			struct cutlass_packet_hdr *packet_info, 
			struct timespec *now);

int
cutlass_file_ack(cutlass_t *cut_handle, conn_t *conn,
		 struct file_transit_info *file_info, uint8_t *clear_packet,
		 struct timespec *now);

int
cutlass_file_ack_parse(cutlass_t *cut_handle, conn_t *conn, 
		       uint8_t *clear_packet,
		       struct cutlass_packet_hdr *packet_info,
		       struct timespec *now);

int
cutlass_file_action_populate(cutlass_t *cut_handle, conn_t *conn,
			     struct file_transit_info *file_info,
			     struct channel *transport_info,
			     struct cut_action_obj *action_obj,
			     int action_type, int direction);

int
cutlass_file_housekeeping(cutlass_t *cut_handle, conn_t *conn,
			  struct file_transit_info *file_info, int direction,
			  struct timespec *now, struct timespec *sleep_time);

struct file_transit_info *
file_info_init(cutlass_t *cut_handle, conn_t *conn, 
	       int direction, uint8_t *filename, 
	       struct cutlass_file_init_hdr *file_init_hdr);

#ifdef __cplusplus
}
#endif

#endif /* FILE_RECV_H */
