/*
  Crypto layer for Cutlass
  (C) 2004 Jack Lloyd <lloyd@randombit.net>
  
  Message encryption stuff. Split off from crypto.h to prevent
  recursive include dependency.
*/

#ifndef CUTLASS_MSG_CRYPT_H__
#define CUTLASS_MSG_CRYPT_H__

/* Link all functions as C functions, not C++ */
#ifdef __cplusplus
extern "C" {
#endif
  
/******************************************************************
* Actual cryptographic operations                                 *
******************************************************************/
/*
   This takes an packet (hdr info + payload), packs it, crypto-izes it, 
   and sends it off. Returns 0 if all is well, <0 if anything failed.
*/
int
cutlass_send_process(cutlass_t* cut_handle,
                     conn_t* conn, const struct cutlass_packet_hdr* hdr,
                     const uint8_t* payload, uint16_t payload_len);

/* This takes the packet we got in, decrypts + verifies it, and unpacks the
   header stuff into hdr. It returns the actual payload (malloc'ed) as the
   return value, the length can be found by looking at hdr->length. If
   anything fails it returns NULL.
*/
uint8_t*
cutlass_recv_process(conn_t* conn, struct cutlass_packet_hdr* hdr,
                     const uint8_t* in_packet, uint16_t in_size);

#ifdef __cplusplus
}
#endif

#endif
