/**
 * Ring buffer header file.
 *
 * Types and function decls for
 * ring.c.
 *
 * Copyright (c) 2004
 *  nash e.f. <nash@solace.net>
 */

#ifndef CUTLASS_RING_H
#define CUTLASS_RING_H


typedef struct cutlass_ring
{
  size_t mbrsize; // member size
  uint32_t size; // # of membrs
  uint32_t read; // read index
  uint32_t write; // write index
  uint8_t *data;
  uint8_t is_full; // 0 if non-full, 1 if full
  pthread_mutex_t lock;
} cutlass_ring_t;


cutlass_ring_t *
cutlass_ring_new( size_t mbrsize, 
                  uint32_t size);

void
cutlass_ring_free(cutlass_ring_t *ring);

int
cutlass_ring_read(cutlass_ring_t *ring, void *read_buf, 
                  uint32_t blocksize, uint32_t max);

int
cutlass_ring_write(cutlass_ring_t *ring, void *write_buf, uint32_t num);

#endif



